| Title: | Quick Response Code (QR Code) / Matrix Barcode Creator |
|---|---|
| Description: | Quick Response codes (QR codes) are a type of matrix bar code and can be used to authenticate transactions, provide access to multi-factor authentication services and enable general data transfer in an image. QR codes use four standardized encoding modes (numeric, alphanumeric, byte/binary, and kanji) to efficiently store data. Matrix barcode generation is performed efficiently in C via the included 'libqrencoder' library created by Kentaro Fukuchi. |
| Authors: | Bob Rudis [aut, cre] (ORCID: <https://orcid.org/0000-0001-5670-2640>), Kentaro Fukuchi [ctb] (libqrencoder) |
| Maintainer: | Bob Rudis <[email protected]> |
| License: | GPL-2 |
| Version: | 0.2.1 |
| Built: | 2026-05-06 08:18:41 UTC |
| Source: | https://github.com/hrbrmstr/qrencoder |
Useful if you want to do your own post-processing
qrencode(to_encode)qrencode(to_encode)
to_encode |
the data to encode |
qrencode("http://rud.is/b")qrencode("http://rud.is/b")
Useful for ggplot::geom_raster
qrencode_df(to_encode)qrencode_df(to_encode)
to_encode |
the data to encode |
head(qrencode_df("http://rud.is/b"))head(qrencode_df("http://rud.is/b"))
Return a QR encoded string as a base 64 encoded inline png
qrencode_png(to_encode)qrencode_png(to_encode)
to_encode |
the data to encode |
data:image/png;base64, is prepended to the encoded png
cat(qrencode_png("http://rud.is/b"))cat(qrencode_png("http://rud.is/b"))
Return a QR encoded string as a raster object
qrencode_raster(to_encode)qrencode_raster(to_encode)
to_encode |
the data to encode |
library(raster) old_mar <- par()$mar par(mar=c(0,0,0,0)) image(qrencode_raster("http://rud.is/b"), asp=1, col=c("white", "black"), axes=FALSE, xlab="", ylab="") par(mar=old_mar)library(raster) old_mar <- par()$mar par(mar=c(0,0,0,0)) image(qrencode_raster("http://rud.is/b"), asp=1, col=c("white", "black"), axes=FALSE, xlab="", ylab="") par(mar=old_mar)
Encodes a string as a QR coder
qrencode_raw(to_encode, version = 0L, level = 0L, hint = 2L, caseinsensitive = 1L)qrencode_raw(to_encode, version = 0L, level = 0L, hint = 2L, caseinsensitive = 1L)
to_encode |
character string to encode |
version |
version of the symbol. If |
level |
error correction level ( |
hint |
tell the library how Japanese Kanji characters should be encoded:
|
caseinsensitive |
case-sensitive( |
http://www.qrcode.com/en/about/version.html
Encodes a string as a QR coder
qrencode_svg(to_encode, version = 0L, level = 0L, hint = 2L, caseinsensitive = 1L, margin = 0L, size = 3L, dpi = 72L)qrencode_svg(to_encode, version = 0L, level = 0L, hint = 2L, caseinsensitive = 1L, margin = 0L, size = 3L, dpi = 72L)
to_encode |
character string to encode |
version |
version of the symbol. If |
level |
error correction level ( |
hint |
tell the library how Japanese Kanji characters should be encoded:
|
caseinsensitive |
case-sensitive( |
margin |
width of the marginsl default is 4 |
size |
module size in dots (pixels); default is 3 |
dpi |
resolution; default = 72 |
http://www.qrcode.com/en/about/version.html
Quick Response codes (QR codes) are a type of matrix bar code and can be used to authenticate transactions, provide access to multi-factor authentication services and enable general data transfer in an image. QR codes use four standardized encoding modes (numeric, alphanumeric, byte/binary, and kanji) to efficiently store data. Matrix barcode generation is performed efficiently in C via the included 'libqrencoder' library created by Kentaro Fukuchi.
Bob Rudis ([email protected])